
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.19.6',
    'branch_nick': 'patch-0-Release__Rucio_1_19_6_preparation',
    'revision_id': 'a8c639a7a70a9e605ad90535d28d2eab04d89cce',
    'revno': 7992
}
